# delimit ;
set more 1;
clear all;
set mem 1G;
set matsize 5000;
set logtype text;
pause on;
*profiler on;
*parameters;
local male_longshape_file 		${global_male_longshape_file};
local female_longshape_file 	${global_female_longshape_file};
local temp_path 				${global_temp_path};
local temp_file					`temp_path'/stata_temp_file2.dta;
local output_path 				${global_output_path}/cohorts;
mkdir `output_path';
local log_filename 				log_cohorts_24feb2016_1pc.txt;

local sex_var male;			*variable with 1 for male, 0 for female;
local wage_var wage;		*variable with wage/salary variable;
local dob_var dob;			*variable with day of birth;
local mob_var mob;			*variable with month of birth;
local yob_var yob;			*variable with year of birth;
local yod_var yod;			*variable with year of death;
local race_var race;		*variable with 1 for white, 0 for other;
local windsor .99999;		*cutoff for windsorizing the top of the distribution;

local first_year 1957;
local last_year 2013;
local r 0;

matrix age_range = (25,55);

*selection parameters;
local min_years = 15; *this is min n of years statisfying annual requirement = 520*0.5*minwage;
local min_avinc1 = 0.5*6*520;
local min_avinc2 = 6*520;
matrix min_avinc = (`min_avinc1',`min_avinc2') ;

*log all output;
cap log close;
log using `output_path'/computations_`log_filename', replace;
noi disp "Starting on ${S_DATE} at ${S_TIME}";
*loop over age ranges;
local nage_config = rowsof(age_range);
forvalues a = 1/`nage_config'{; 
	
	local first_age = age_range[`a',1];
	local last_age = age_range[`a',2];
	local nyrs_age = `last_age'-`first_age'+1;

	*loop over sexes;
	forvalues s = 0/2{;
		
		*loops over wage and total income;
		foreach var in wage {;
			noi disp " variable: `var'";
		
			*use long data set;
			if (`s'==1) use idd year rwage rminwg age yob using `male_longshape_file' if age>=`first_age' & age<=`last_age', clear;
			if (`s'==0) use idd year rwage rminwg age yob using `female_longshape_file' if age>=`first_age' & age<=`last_age', clear;
			if `s'==2{;
				use idd year rwage rminwg age yob using `male_longshape_file' if age>=`first_age' & age<=`last_age', clear;
				append using `female_longshape_file', keep(idd year rwage rselfinc rminwg age yob);
				keep if age>=`first_age' & age<=`last_age';
			}; 
			
			rename rwage rwageinc;
			
			*only keep individuals with complete data;
			sort id age;
			by id: gen byte age1 = age[1];
			by id: gen byte ageN = age[_N];
			drop if age1>`first_age';
			drop if ageN<`last_age';
			drop ageN;
			
			*index cohort by year at first_age;
			gen int cohort = yob + `first_age';
			drop yob;
			
			*selection: no. of years satisfying 0.5*minimum wages;
			by id: egen byte npresent_`var'inc = total(cond(r`var'inc>=0.5*rminwg*520 & r`var'inc~=.,1,0));
			by id: egen byte npresent_`var'inc_2534 = total(cond(r`var'inc>=0.5*rminwg*520 & r`var'inc~=. & age >= 25 & age <= 34,1,0));
			by id: egen byte npresent_`var'inc_3544 = total(cond(r`var'inc>=0.5*rminwg*520 & r`var'inc~=. & age >= 35 & age <= 44,1,0));
			by id: egen byte npresent_`var'inc_4555 = total(cond(r`var'inc>=0.5*rminwg*520 & r`var'inc~=. & age >= 45 & age <= 55,1,0));
			
			di "frequencies of num yrs present";
			tab npresent_`var'inc if age==age1, m;
			drop rminwg;
			
			*windsorize the data at the 99.999th percentile in each year;
			sort year r`var'inc;
			by year: egen num_nm = count(r`var'inc);
			by year: gen r`var'incwindsor = r`var'inc[ceil(`windsor'*num_nm[1])];
			replace r`var'inc = r`var'incwindsor if r`var'inc > r`var'incwindsor;
			drop num_nm r`var'incwindsor year;
		
			*lifetime earnings and taxes;
			sort id age;
			by id: egen pv`var'inc_r`r' = total((r`var'inc)*((1+`r'/100)^(`first_age'-age)));
			drop r`var'inc;
			
			*store data;
			compress;
			save `temp_file', replace;

			*distribution of lifetime income by cohort;
			forvalues sel = 0(3)3{;
			
				*load back data: only need one observation per person;
				use `temp_file' if age==age1, clear;
				
				*selection criteria;
				if (`sel'==0) keep if pv`var'inc_r`r'~=.;
				if (`sel'==1) keep if pv`var'inc_r`r'/`nyrs_age' >= min_avinc[1,1] & pv`var'inc_r`r'~=.;	
				if (`sel'==2) keep if pv`var'inc_r`r'/`nyrs_age' >= min_avinc[1,2] & pv`var'inc_r`r'~=.;	
				if (`sel'==3) keep if pv`var'inc_r`r'/`nyrs_age' >= min_avinc[1,1] & pv`var'inc_r`r'~=. & npresent_`var'inc>=`min_years';	
		
				*drops unneccessary variables;
				drop age age1;
				
				*define log pv income;
				gen lpv`var'inc_r`r' = log(pv`var'inc_r`r');
				
				*average earnings counting and not counting years with no earnings;
				gen pv`var'inc_r`r'_peryr = pv`var'inc_r`r'/ npresent_`var'inc;
				gen pv`var'inc_r`r'_peryr_uncond = pv`var'inc_r`r'/ `nyrs_age';
				
				*stats for pv income in each cohort;
				noi disp "working on lifetime income by cohort, age range: `first_age' to `last_age'; sex: `s'; selection : `sel'";	
				
				*stats on level of lifetime income;
				sort cohort pv`var'inc_r`r';
				by cohort: egen mean = mean(pv`var'inc_r`r');
				by cohort: egen sd = sd(pv`var'inc_r`r');
				by cohort: egen skew = skew(pv`var'inc_r`r');
				by cohort: egen kurt = kurt(pv`var'inc_r`r');
				foreach n in 1 2 3 4 5 10 20 25 30 40 50 60 70 75 80 90 95 96 97 98 99{;
					by cohort: gen p`n' = pv`var'inc_r`r'[ceil((`n'/100)*_N)];
				};
				by cohort: gen p999 = pv`var'inc_r`r'[ceil((99.9/100)*_N)];
				by cohort: gen p9999 = pv`var'inc_r`r'[ceil((99.99/100)*_N)];
				
				*stats on log of lifetime income;
				by cohort: egen meanlog = mean(lpv`var'inc_r`r');
				by cohort: egen sdlog = sd(lpv`var'inc_r`r');
				by cohort: egen skewlog = skew(lpv`var'inc_r`r');
				by cohort: egen kurtlog = kurt(lpv`var'inc_r`r');
				
				*stats on average yearly income;
				by cohort: egen meanperyr= mean(pv`var'inc_r`r'_peryr);
				by cohort: egen sdperyr= sd(pv`var'inc_r`r'_peryr);
				
				by cohort: egen meanperyr_uncond= mean(pv`var'inc_r`r'_peryr_uncond);
				by cohort: egen sdperyr_uncond= sd(pv`var'inc_r`r'_peryr_uncond);
				
				*number of observations and average years present;
				by cohort: egen N = count(pv`var'inc_r`r');
				by cohort: egen npresent = mean(npresent_`var'inc);
				by cohort: egen npresent_2534 = mean(npresent_`var'inc_2534);
				by cohort: egen npresent_3544 = mean(npresent_`var'inc_3544);
				by cohort: egen npresent_4555 = mean(npresent_`var'inc_4555);
									
				*calculates gini of lifetime income;
				gen tmp = pv`var'inc_r`r';
				replace tmp = . if pv`var'inc_r`r' <= 0;
				by cohort: egen mean1 = mean(pv`var'inc_r`r');
				by cohort: egen N1 = count(pv`var'inc_r`r');
				by cohort: egen rank = rank(pv`var'inc_r`r') if pv`var'inc_r`r' > 0, field;
				replace rank = 0 if rank == .;
				by cohort: egen Gtemp = total(rank*tmp);
				gen gini = (N1+1)/(N1-1) - 2/(N1*(N1-1)*mean1)*Gtemp;
				drop tmp mean1 N1 rank Gtemp;
				
				*tags the first line in each cohort for output;
				by cohort: gen cohorttag = 1 if _n == 1;
				
				*outputs calculations;
				outsheet cohort 
				mean sd skew kurt
				meanlog sdlog skewlog kurtlog
				p1 p2 p3 p4 p5 p10 p20 p25 p30 p40 p50 p60 p70  
		 		p75 p80 p90 p95 p96 p97 p98 p99 p999 p9999 
				meanperyr sdperyr meanperyr_uncond sdperyr_uncond
				N npresent npresent_2534 npresent_3544 npresent_4555 gini  
		 		using `output_path'/cohortdist_`var'inc_sel`sel'_`first_age'_`last_age'_sex`s'.txt  if cohorttag == 1, replace;
				
				*drops outputted variables;
				drop cohorttag
				mean sd skew kurt
				meanlog sdlog skewlog kurtlog
				p1 p2 p3 p4 p5 p10 p20 p25 p30 p40 p50 p60 p70  
		 		p75 p80 p90 p95 p96 p97 p98 p99 p999 p9999 
				meanperyr sdperyr meanperyr_uncond sdperyr_uncond
				N npresent npresent_2534 npresent_3544 npresent_4555 gini;
				
				*stats for pv income by lifetime income percentile in each cohort;
				noi disp "working on lifetime income by lifetime income percentile in each cohort, age range: `first_age' to `last_age'; sex: `s'; selection : `sel'";
				
				*percentile in lifetime earnings distribution for their cohort;
				foreach v in pv`var'inc_r`r' {;
					gen byte lifepc_`v' = 1;
					sort cohort `v';
					forvalues n = 1/100{;
						by cohort: replace lifepc_`v' = `n'+1 if `v' > `v'[ceil(`n'/100*_N)];
					};
				};
				
				
				*stats on level of lifetime income;
				sort cohort lifepc_pv`var'inc_r`r' pv`var'inc_r`r';
				by cohort lifepc_pv`var'inc_r`r': egen mean = mean(pv`var'inc_r`r');
				by cohort lifepc_pv`var'inc_r`r': egen sd = sd(pv`var'inc_r`r');
				by cohort lifepc_pv`var'inc_r`r': egen skew = skew(pv`var'inc_r`r');
				by cohort lifepc_pv`var'inc_r`r': egen kurt = kurt(pv`var'inc_r`r');

				*stats on log of lifetime income;
				by cohort lifepc_pv`var'inc_r`r': egen meanlog = mean(lpv`var'inc_r`r');
				by cohort lifepc_pv`var'inc_r`r': egen sdlog = sd(lpv`var'inc_r`r');
				by cohort lifepc_pv`var'inc_r`r': egen skewlog = skew(lpv`var'inc_r`r');
				by cohort lifepc_pv`var'inc_r`r': egen kurtlog = kurt(lpv`var'inc_r`r');
				
				*stats on average yearly income;
				by cohort lifepc_pv`var'inc_r`r': egen meanperyr= mean(pv`var'inc_r`r'_peryr);
				by cohort lifepc_pv`var'inc_r`r': egen sdperyr= sd(pv`var'inc_r`r'_peryr);
				
				by cohort lifepc_pv`var'inc_r`r': egen meanperyr_uncond= mean(pv`var'inc_r`r'_peryr_uncond);
				by cohort lifepc_pv`var'inc_r`r': egen sdperyr_uncond= sd(pv`var'inc_r`r'_peryr_uncond);
				
				*number of observations and average years present;
				by cohort lifepc_pv`var'inc_r`r': egen N = count(pv`var'inc_r`r');
				by cohort lifepc_pv`var'inc_r`r': egen npresent = mean(npresent_`var'inc);
				by cohort lifepc_pv`var'inc_r`r': egen npresent_2534 = mean(npresent_`var'inc_2534);
				by cohort lifepc_pv`var'inc_r`r': egen npresent_3544 = mean(npresent_`var'inc_3544);
				by cohort lifepc_pv`var'inc_r`r': egen npresent_4555 = mean(npresent_`var'inc_4555);
				
				*tags the first line in each cohort for output;
				by cohort lifepc_pv`var'inc_r`r': gen cohorttag = 1 if _n == 1;
				
				*outputs calculations;
				outsheet cohort lifepc_pv`var'inc_r`r' 
				mean sd skew kurt
				meanlog sdlog skewlog kurtlog
				meanperyr sdperyr meanperyr_uncond sdperyr_uncond
				N npresent npresent_2534 npresent_3544 npresent_4555
		 		using `output_path'/bycohortlifepc_cohortdist_`var'inc_sel`sel'_`first_age'_`last_age'_sex`s'.txt if cohorttag == 1, replace;
				
				*drops outputted variables;
				drop cohorttag lifepc_pv`var'inc_r`r' 
				mean sd skew kurt
				meanlog sdlog skewlog kurtlog
				meanperyr sdperyr meanperyr_uncond sdperyr_uncond
				N npresent npresent_2534 npresent_3544 npresent_4555;
				
				
								
				*stats for pv income by years worked in each cohort;
				noi disp "working on lifetime income by years worked in each cohort, age range: `first_age' to `last_age'; sex: `s'; selection : `sel'";
				
				*stats on level of lifetime income;
				sort cohort npresent_`var'inc pv`var'inc_r`r';
				by cohort npresent_`var'inc: egen mean = mean(pv`var'inc_r`r');
				by cohort npresent_`var'inc: egen sd = sd(pv`var'inc_r`r');
				by cohort npresent_`var'inc: egen skew = skew(pv`var'inc_r`r');
				by cohort npresent_`var'inc: egen kurt = kurt(pv`var'inc_r`r');
				
				*stats on log of lifetime income;
				by cohort npresent_`var'inc: egen meanlog = mean(lpv`var'inc_r`r');
				by cohort npresent_`var'inc: egen sdlog = sd(lpv`var'inc_r`r');
				by cohort npresent_`var'inc: egen skewlog = skew(lpv`var'inc_r`r');
				by cohort npresent_`var'inc: egen kurtlog = kurt(lpv`var'inc_r`r');
				
				*stats on average yearly income;
				by cohort npresent_`var'inc: egen meanperyr= mean(pv`var'inc_r`r'_peryr);
				by cohort npresent_`var'inc: egen sdperyr= sd(pv`var'inc_r`r'_peryr);
				
				by cohort npresent_`var'inc: egen meanperyr_uncond= mean(pv`var'inc_r`r'_peryr_uncond);
				by cohort npresent_`var'inc: egen sdperyr_uncond= sd(pv`var'inc_r`r'_peryr_uncond);
				
				*number of observations and average years present;
				by cohort npresent_`var'inc: egen N = count(pv`var'inc_r`r');
				by cohort npresent_`var'inc: egen npresent = mean(npresent_`var'inc);
				by cohort npresent_`var'inc: egen npresent_2534 = mean(npresent_`var'inc_2534);
				by cohort npresent_`var'inc: egen npresent_3544 = mean(npresent_`var'inc_3544);
				by cohort npresent_`var'inc: egen npresent_4555 = mean(npresent_`var'inc_4555);
				
				*tags the first line in each year worked for output;
				by cohort npresent_`var'inc: gen tag = 1 if _n == 1;
				
				*outputs calculations;
				outsheet cohort npresent_`var'inc 
				mean sd skew kurt
				meanlog sdlog skewlog kurtlog
				meanperyr sdperyr meanperyr_uncond sdperyr_uncond
				N npresent npresent_2534 npresent_3544 npresent_4555
		 		using `output_path'/bycohortnpresent_lifedist_`var'inc_sel`sel'_`first_age'_`last_age'_sex`s'.txt if tag == 1, replace;
				
				*drops outputted variables;
				drop tag  
				mean sd skew kurt
				meanlog sdlog skewlog kurtlog
				meanperyr sdperyr meanperyr_uncond sdperyr_uncond
				N npresent npresent_2534 npresent_3544 npresent_4555;
			};
		};
	};	
};	
noi disp "Ending on ${S_DATE} at ${S_TIME}";	
*close log file;
cap log close;
*profiler off;
*profiler report;

