# delimit ;
set more 1;
clear all;
set mem 1G;
set matsize 5000;
set logtype text;
pause on;
*profiler on;
*parameters;
local male_longshape_file 		${glo_male_longshape_file_1pc};
local female_longshape_file 	${glo_female_longshape_file_1pc};
local temp_path 				${glo_temp_path};
local temp_file					`temp_path'/stata_temp_file2.dta;
local output_path 				${glo_output_path}/cohorts;
mkdir `output_path';
local log_filename 				log_cohorts_25sep2016_1pc.txt;

local sex_var male;			*variable with 1 for male, 0 for female;
local wage_var wage;		*variable with wage/salary variable;
local dob_var dob;			*variable with day of birth;
local mob_var mob;			*variable with month of birth;
local yob_var yob;			*variable with year of birth;
local yod_var yod;			*variable with year of death;
local race_var race;		*variable with 1 for white, 0 for other;
local windsor .99999;		*cutoff for windsorizing the top of the distribution;

local first_year 1957;
local last_year 2013;
local r 0;

matrix age_range = (25,35\35,45\45,55\25,45\35,55);

*selection parameters;
local min_years = 15; *this is min n of years statisfying annual requirement = 520*0.5*minwage;
local min_avinc1 = 0.5*6*520;
local min_avinc2 = 6*520;
matrix min_avinc = (`min_avinc1',`min_avinc2') ;

*log all output;
cap log close;
log using `output_path'/computations_`log_filename', replace;
noi disp "Starting on ${S_DATE} at ${S_TIME}";
*loop over age ranges;
local nage_config = rowsof(age_range);
forvalues a = 1/`nage_config'{; 
	
	local first_age = age_range[`a',1];
	local last_age = age_range[`a',2];
	local nyrs_age = `last_age'-`first_age'+1;

	*loop over sexes;
	forvalues s = 0/2{;
		
		*loops over wage and total income;
		foreach var in wage {;
			noi disp " variable: `var'";
		
			*use long data set;
			if (`s'==1) use idd year rwage rminwg age yob using `male_longshape_file' if age>=`first_age' & age<=`last_age', clear;
			if (`s'==0) use idd year rwage rminwg age yob using `female_longshape_file' if age>=`first_age' & age<=`last_age', clear;
			if `s'==2{;
				use idd year rwage rminwg age yob using `male_longshape_file' if age>=`first_age' & age<=`last_age', clear;
				append using `female_longshape_file', keep(idd year rwage rselfinc rminwg age yob);
				keep if age>=`first_age' & age<=`last_age';
			}; 
			
			rename rwage rwageinc;
			
			*only keep individuals with complete data;
			sort id age;
			by id: gen byte age1 = age[1];
			by id: gen byte ageN = age[_N];
			drop if age1>`first_age';
			drop if ageN<`last_age';
			drop ageN;
			
			*index cohort by year at 25;
			gen int cohort = yob + 25;
			drop yob;
			
			*selection: no. of years satisfying 0.5*minimum wages;
			by id: egen byte npresent_`var'inc = total(cond(r`var'inc>=0.5*rminwg*520 & r`var'inc~=.,1,0));

			di "frequencies of num yrs present";
			tab npresent_`var'inc if age==age1, m;
			drop rminwg;
			
			*windsorize the data at the 99.999th percentile in each year;
			sort year r`var'inc;
			by year: egen num_nm = count(r`var'inc);
			by year: gen r`var'incwindsor = r`var'inc[ceil(`windsor'*num_nm[1])];
			replace r`var'inc = r`var'incwindsor if r`var'inc > r`var'incwindsor;
			drop num_nm r`var'incwindsor year;
		
			*lifetime earnings and taxes;
			sort id age;
			by id: egen pv`var'inc_r`r' = total((r`var'inc)*((1+`r'/100)^(`first_age'-age)));
			drop r`var'inc;
			
			*store data;
			compress;
			save `temp_file', replace;

			*distribution of lifetime income by cohort;
			forvalues sel = 0(3)3{;
			
				*load back data: only need one observation per person;
				use `temp_file' if age==age1, clear;
				
				*selection criteria;
				if (`sel'==0) keep if pv`var'inc_r`r'~=.;
				if (`sel'==1) keep if pv`var'inc_r`r'/`nyrs_age' >= min_avinc[1,1] & pv`var'inc_r`r'~=.;	
				if (`sel'==2) keep if pv`var'inc_r`r'/`nyrs_age' >= min_avinc[1,2] & pv`var'inc_r`r'~=.;	
				if (`sel'==3) keep if pv`var'inc_r`r'/`nyrs_age' >= min_avinc[1,1] & pv`var'inc_r`r'~=. & npresent_`var'inc>=`nyrs_age'/2;	
		
				*drops unneccessary variables;
				drop age age1;
				
				*define log pv income;
				gen lpv`var'inc_r`r' = log(pv`var'inc_r`r');
				
				*average earnings counting and not counting years with no earnings;
				gen pv`var'inc_r`r'_peryr = pv`var'inc_r`r'/ npresent_`var'inc;
				gen pv`var'inc_r`r'_peryr_uncond = pv`var'inc_r`r'/ `nyrs_age';
				gen lpv`var'inc_r`r'_peryr = log(pv`var'inc_r`r'_peryr);
				gen lpv`var'inc_r`r'_peryr_uncond = log(pv`var'inc_r`r'_peryr_uncond);
				
				*stats for pv income in each cohort;
				noi disp "working on lifetime income by cohort, age range: `first_age' to `last_age'; sex: `s'; selection : `sel'";	
				
				*stats on level of lifetime income;
				sort cohort pv`var'inc_r`r';
				by cohort: egen mean = mean(pv`var'inc_r`r');
				by cohort: egen sd = sd(pv`var'inc_r`r');
				by cohort: egen skew = skew(pv`var'inc_r`r');
				by cohort: egen kurt = kurt(pv`var'inc_r`r');
				by cohort: egen N = count(pv`var'inc_r`r');
				foreach n in 5 10 25 50 75 80 90 95 99{;
					by cohort: gen p`n' = pv`var'inc_r`r'[ceil((`n'/100)*N[1])];
				};
				by cohort: egen npresent = mean(npresent_`var'inc);
				
				*stats on log of lifetime income;
				by cohort: egen Nlog = count(lpv`var'inc_r`r');
				by cohort: egen meanlog = mean(lpv`var'inc_r`r');
				by cohort: egen sdlog = sd(lpv`var'inc_r`r');
				by cohort: egen skewlog = skew(lpv`var'inc_r`r');
				by cohort: egen kurtlog = kurt(lpv`var'inc_r`r');
				
				
				*stats on level of lifetime income;
				sort cohort pv`var'inc_r`r'_peryr;
				by cohort: egen mean_peryr = mean(pv`var'inc_r`r'_peryr);
				by cohort: egen sd_peryr = sd(pv`var'inc_r`r'_peryr);
				by cohort: egen skew_peryr = skew(pv`var'inc_r`r'_peryr);
				by cohort: egen kurt_peryr = kurt(pv`var'inc_r`r'_peryr);
				by cohort: egen N_peryr = count(pv`var'inc_r`r'_peryr);
				foreach n in 5 10 25 50 75 80 90 95 99 {;
					by cohort: gen p`n'_peryr = pv`var'inc_r`r'_peryr[ceil((`n'/100)*N_peryr[1])];
				};
				by cohort: egen mean_logperyr = mean(lpv`var'inc_r`r'_peryr);
				by cohort: egen sd_logperyr = sd(lpv`var'inc_r`r'_peryr);
				by cohort: egen skew_logperyr = skew(lpv`var'inc_r`r'_peryr);
				by cohort: egen kurt_logperyr = kurt(lpv`var'inc_r`r'_peryr);
				by cohort: egen N_logperyr = count(lpv`var'inc_r`r'_peryr);
				
				*tags the first line in each cohort for output;
				by cohort: gen cohorttag = 1 if _n == 1;
				
				*outputs calculations;
				outsheet cohort 
				mean sd skew kurt N npresent 
				meanlog sdlog skewlog kurtlog Nlog
				p5 p10 p25 p50 p75 p80 p90 p95 p99  
				mean_peryr sd_peryr skew_peryr kurt_peryr N_peryr
				p5_peryr p10_peryr p25_peryr p50_peryr p75_peryr p80_peryr p90_peryr p95_peryr p99_peryr
				mean_logperyr sd_logperyr skew_logperyr kurt_logperyr N_logperyr
		 		using `output_path'/cohortdist_`var'inc_sel`sel'_`first_age'_`last_age'_sex`s'.txt  if cohorttag == 1, replace;
				
				*drops outputted variables;
				drop cohorttag
				mean sd skew kurt N npresent 
				meanlog sdlog skewlog kurtlog Nlog
				p5 p10 p25 p50 p75 p80 p90 p95 p99  
				mean_peryr sd_peryr skew_peryr kurt_peryr N_peryr
				p5_peryr p10_peryr p25_peryr p50_peryr p75_peryr p80_peryr p90_peryr p95_peryr p99_peryr
				mean_logperyr sd_logperyr skew_logperyr kurt_logperyr N_logperyr;
				
			};
		};
	};	
};	
noi disp "Ending on ${S_DATE} at ${S_TIME}";	
*close log file;
cap log close;
*profiler off;
*profiler report;

