# delimit ;
set more 1;
clear all;
set mem 1G;
set matsize 5000;
set logtype text;
pause on;
*profiler on;
*parameters;
local male_longshape_file 		${glo_male_longshape_file_1pc};
local female_longshape_file 	${glo_female_longshape_file_1pc};
local temp_path 				${glo_temp_path};
local temp_file					`temp_path'/stata_temp_file2.dta;
local output_path 				${glo_output_path}/yearx_partiallc_1pc;
mkdir `output_path';
local log_filename 				log_yearx_partiallc_04oct2016_1pc.txt;

local sex_var male;			*variable with 1 for male, 0 for female;
local wage_var wage;		*variable with wage/salary variable;
local dob_var dob;			*variable with day of birth;
local mob_var mob;			*variable with month of birth;
local yob_var yob;			*variable with year of birth;
local yod_var yod;			*variable with year of death;
local race_var race;		*variable with 1 for white, 0 for other;
local windsor .99999;		*cutoff for windsorizing the top of the distribution;

local first_year 1957;
local last_year 2013;
local r 0;

matrix age_range = (25,55);

*selection parameters;
local min_years = 15; *this is min n of years statisfying annual requirement = 520*0.5*minwage;
local min_avinc1 = 0.5*6*520;
local min_avinc2 = 6*520;
matrix min_avinc = (`min_avinc1',`min_avinc2') ;

*log all output;
cap log close;
log using `output_path'/computations_`log_filename', replace;
noi disp "Starting on ${S_DATE} at ${S_TIME}";
*loop over age ranges;
local nage_config = rowsof(age_range);
forvalues a = 1/`nage_config'{; 
	
	local first_age = age_range[`a',1];
	local last_age = age_range[`a',2];
	local nyrs_age = `last_age'-`first_age'+1;

	*loop over sexes;
	forvalues s = 0/2{;
		
		*loops over wage and total income;
		foreach var in wage {;
			noi disp " variable: `var'";
		
			*use long data set;
			if (`s'==1) use idd year rwage rminwg age yob using `male_longshape_file' if age>=`first_age' & age<=`last_age', clear;
			if (`s'==0) use idd year rwage rminwg age yob using `female_longshape_file' if age>=`first_age' & age<=`last_age', clear;
			if `s'==2{;
				use idd year rwage rminwg age yob using `male_longshape_file' if age>=`first_age' & age<=`last_age', clear;
				append using `female_longshape_file', keep(idd year rwage rselfinc rminwg age yob);
				keep if age>=`first_age' & age<=`last_age';
			}; 
			
			rename rwage rwageinc;
			
			sort id age;
			
			*index cohort by year at first_age;
			gen int cohort = yob + `first_age';
			drop yob;
			
			*selection: no. of years satisfying 0.5*minimum wages;
			by id: egen byte npresent_`var'inc = total(cond(r`var'inc>=0.5*rminwg*520 & r`var'inc~=.,1,0));
			
			*possible number of years available in the data;
			gen byte maxyrs = min(cohort - `first_year' + `nyrs_age',`nyrs_age') if cohort < `first_year';
			replace maxyrs = min(`last_year' - cohort + 1,`nyrs_age') if cohort >= `first_year';
		
			*windsorize the data at the 99.999th percentile in each year;
			sort year r`var'inc;
			by year: egen num_nm = count(r`var'inc);
			by year: gen r`var'incwindsor = r`var'inc[ceil(`windsor'*num_nm[1])];
			replace r`var'inc = r`var'incwindsor if r`var'inc > r`var'incwindsor;
			drop num_nm r`var'incwindsor;
			
			*lifetime earnings and taxes;
			sort id age;
			by id: egen pv`var'inc_r`r' = total((r`var'inc)*((1+`r'/100)^(`first_age'-age)));
				
			*store data;
			compress;
			save `temp_file', replace;

			
			*distribution of yearly income;
			forvalues sel = 3(3)3{;
			
				*load back data;
				use `temp_file', clear;
				
				*selection criteria;	
				if (`sel'==0) keep if pv`var'inc_r`r'~=.;
				if (`sel'==1) keep if pv`var'inc_r`r'/maxyrs >= min_avinc[1,1] & pv`var'inc_r`r'~=.;	
				if (`sel'==2) keep if pv`var'inc_r`r'/maxyrs >= min_avinc[1,2] & pv`var'inc_r`r'~=.;	
				if (`sel'==3) keep if pv`var'inc_r`r'/maxyrs >= min_avinc[1,1] & pv`var'inc_r`r'~=. & npresent_`var'inc>=0.5*maxyrs;	
						
				drop maxyrs pv`var'inc_r`r' npresent_`var'inc;
				
				*stats for income in each year;
				noi disp "working on yearly cross section, age range: `first_age' to `last_age'; sex: `s'; selection : `sel'";	
				
				*impose annual min wage selection;
				keep if r`var'inc>=0.5*rminwg*520 & r`var'inc~=.;
				drop rminwg;
				
				*stats by year;
				sort year r`var'inc;
				gen lr`var'inc = log(r`var'inc);
				by year: egen meanlog = mean(lr`var'inc);
				by year: egen sdlog = sd(lr`var'inc);
				by year: egen N = count(r`var'inc);
				by year: egen Nlog = count(lr`var'inc);
				foreach n in 10 25 50 75 90 95 98 99{;
					by year: gen p`n' = r`var'inc[ceil((`n'/100)*_N)];
				};
				by year: gen p999 = r`var'inc[ceil((99.9/100)*_N)];
				
				*tags the first line in each year for output;
				by year: gen byte yeartag = 1 if _n == 1;
				
				*outputs calculations;
				outsheet year
				meanlog sdlog N Nlog
				p10 p25 p50 p75 p90 p95 p98 p99 p999
		 		using `output_path'/yearx_r`var'inc_sel`sel'_`first_age'_`last_age'_sex`s'.txt if yeartag == 1, replace;
				
				*drops outputted variables;
				drop yeartag
				meanlog sdlog N Nlog
				p10 p25 p50 p75 p90 p95 p98 p99 p999;
			};
		};
	};	
};	
noi disp "Ending on ${S_DATE} at ${S_TIME}";	
*close log file;
cap log close;
*profiler off;
*profiler report;

